@@ -5,7 +5,7 @@ use warnings;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '0.101_01';
+$VERSION = '0.102_01';
 
 use DateTime 0.08;
 @ISA = 'DateTime';
@@ -188,10 +188,12 @@ year 1BC (there was no year 0AD!), -1 the year 2BC, etc.
 
 =head1 SUPPORT
 
-Support for this module is provided via the datetime@perl.org email
-list. See http://lists.perl.org/ for more details.
+Support for this module is provided via the F<datetime@perl.org> email
+list. See L<https://lists.perl.org/> for more details.
 
-Bug reports will be accepted as RT tickets or by mail to Wyant.
+Please report bugs to
+L<https://github.com/trwyant/perl-DateTime-Calendar-Julian/issues>, or
+in electronic mail to F<wyant@cpan.org>.
 
 =head1 AUTHOR
 
@@ -203,7 +205,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.
 
-Copyright (C) 2018-2019 Thomas R. Wyant, III
+Copyright (C) 2018-2021 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
